@@ -10,12 +10,20 @@ import sys
 import threading
 import time
 import traceback
-import urlparse
 import urllib
 import uuid
 
 import requests
 
+try:
+    # Python 3
+    import urllib.parse as urlparse
+    from urllib.parse import urlencode
+except ImportError:
+    # Python 2
+    import urlparse
+    from urllib import urlencode
+
 
 # import request objects from various frameworks, if available
 try:
@@ -28,6 +36,11 @@ try:
 except ImportError:
     DjangoHttpRequest = None
 
+try:
+    from rest_framework.request import Request as RestFrameworkRequest
+except ImportError:
+    RestFrameworkRequest = None
+
 try:
     from werkzeug.wrappers import Request as WerkzeugRequest
 except ImportError:
@@ -99,7 +112,7 @@ log = logging.getLogger(__name__)
 
 agent_log = None
 
-VERSION = '0.6.2'
+VERSION = '0.7.0'
 DEFAULT_ENDPOINT = 'https://api.rollbar.com/api/1/'
 DEFAULT_TIMEOUT = 3
 
@@ -107,6 +120,7 @@ DEFAULT_TIMEOUT = 3
 # configure by calling init() or overriding directly
 SETTINGS = {
     'access_token': None,
+    'enabled': True,
     'environment': 'production',
     'exception_level_filters': [],
     'root': None,  # root path to your code
@@ -180,7 +194,7 @@ def report_exc_info(exc_info=None, request=None, extra_data=None, payload_data=N
 
     try:
         return _report_exc_info(exc_info, request, extra_data, payload_data)
-    except Exception, e:
+    except Exception as e:
         log.exception("Exception while reporting exc_info to Rollbar. %r", e)
 
 
@@ -196,7 +210,7 @@ def report_message(message, level='error', request=None, extra_data=None, payloa
     """
     try:
         return _report_message(message, level, request, extra_data, payload_data)
-    except Exception, e:
+    except Exception as e:
         log.exception("Exception while reporting message to Rollbar. %r", e)
 
 
@@ -427,10 +441,15 @@ def _report_message(message, level, request, extra_data, payload_data):
 
 
 def _check_config():
+    if not SETTINGS.get('enabled'):
+        log.info("pyrollbar: Not reporting because rollbar is disabled.")
+        return False
+
     # make sure we have an access_token
     if not SETTINGS.get('access_token'):
         log.warning("pyrollbar: No access_token provided. Please configure by calling rollbar.init() with your access token.")
         return False
+
     return True
 
 
@@ -439,7 +458,7 @@ def _build_base_data(request, level='error'):
         'timestamp': int(time.time()),
         'environment': SETTINGS['environment'],
         'level': level,
-        'language': 'python',
+        'language': 'python %s' % '.'.join(str(x) for x in sys.version_info[:3]),
         'notifier': SETTINGS['notifier'],
         'uuid': str(uuid.uuid4()),
     }
@@ -456,7 +475,7 @@ def _build_base_data(request, level='error'):
 def _add_person_data(data, request):
     try:
         person_data = _build_person_data(request)
-    except Exception, e:
+    except Exception as e:
         log.exception("Exception while building person data for Rollbar paylooad: %r", e)
     else:
         if person_data:
@@ -526,7 +545,7 @@ def _add_request_data(data, request):
     try:
         request_data = _build_request_data(request)
         request_data = _scrub_request_data(request_data)
-    except Exception, e:
+    except Exception as e:
         log.exception("Exception while building request_data for Rollbar payload: %r", e)
     else:
         if request_data:
@@ -547,6 +566,10 @@ def _build_request_data(request):
     if DjangoHttpRequest and isinstance(request, DjangoHttpRequest):
         return _build_django_request_data(request)
 
+    # django rest framework
+    if RestFrameworkRequest and isinstance(request, RestFrameworkRequest):
+        return _build_django_request_data(request)
+
     # werkzeug (flask)
     if WerkzeugRequest and isinstance(request, WerkzeugRequest):
         return _build_werkzeug_request_data(request)
@@ -589,7 +612,7 @@ def _scrub_request_url(url_string):
 
     # use dash for replacement character so it looks better since it wont be url escaped
     scrubbed_qs_params = _scrub_request_params(qs_params, replacement_character='-')
-    scrubbed_qs = urllib.urlencode(scrubbed_qs_params, doseq=True)
+    scrubbed_qs = urlencode(scrubbed_qs_params, doseq=True)
 
     scrubbed_url = (url.scheme, url.netloc, url.path, url.params, scrubbed_qs, url.fragment)
     scrubbed_url_string = urlparse.urlunparse(scrubbed_url)
@@ -659,7 +682,7 @@ def _build_django_request_data(request):
 
     # headers
     headers = {}
-    for k, v in request.environ.iteritems():
+    for k, v in request.environ.items():
         if k.startswith('HTTP_'):
             header_name = '-'.join(k[len('HTTP_'):].replace('_', ' ').title().split(' '))
             headers[header_name] = v
@@ -747,7 +770,7 @@ def _build_payload(data):
 def _send_payload(payload):
     try:
         _post_api('item/', payload)
-    except Exception, e:
+    except Exception as e:
         log.exception('Exception while posting item %r', e)
 
 
@@ -775,7 +798,7 @@ def _parse_response(path, access_token, params, resp):
 
     try:
         data = resp.text
-    except Exception, e:
+    except Exception as e:
         data = resp.content
         log.error('resp.text is undefined, resp.content is %r', resp.content)
 
@@ -825,7 +848,7 @@ def dict_merge(a, b):
     if not isinstance(b, dict):
         return b
     result = copy.deepcopy(a)
-    for k, v in b.iteritems():
+    for k, v in b.items():
         if k in result and isinstance(result[k], dict):
             result[k] = dict_merge(result[k], v)
         else:
